// Copyright (c) 2013 by István Váradi

// This file is part of VSCPL, a simple cross-platform utility library

// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:

// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.

// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

#ifndef HU_VARADIISTVAN_SCPL_IO_WAITER_H
#define HU_VARADIISTVAN_SCPL_IO_WAITER_H
//------------------------------------------------------------------------------

#if 0 // The public interface of Waiter

//------------------------------------------------------------------------------

namespace hu { namespace varadiistvan { namespace scpl { namespace io {

//------------------------------------------------------------------------------

/**
 * Class that can be used to register waitable objects and then wait
 * for them. The objects are registered when they created and a Waiter
 * instance is passed to them.
 */
class Waiter : public Failable
{
public:
    /**
     * Wait for any if the waitables to become ready or until a
     * timeout expires.
     *
     * If any of the waitables are ready, the function returns immediately.
     *
     * @return true if any of the waitables has become ready, false if
     * the timeout occurs.
     */
    bool wait(int timeout = -1);
};

//------------------------------------------------------------------------------

} /* namespace hu::varadiistvan::scpl::io */ } /* namespace hu::varadiistvan::scpl */ } /* namespace hu::varadiistvan */ } /* namespace hu */

//------------------------------------------------------------------------------

#endif // 0, The public interface of Waiter

//------------------------------------------------------------------------------

#include "hu/varadiistvan/scpl/config.h"

//------------------------------------------------------------------------------

#if TARGET_API_POSIX

#include "_posix/Waiter.h"

//------------------------------------------------------------------------------

#elif TARGET_API_WIN32 || TARGET_API_WIN64

#include "_win32/Waiter.h"

//------------------------------------------------------------------------------

#else

#error "Not implemented for this target!"

#endif

//------------------------------------------------------------------------------
#endif // HU_VARADIISTVAN_SCPL_WAITER_H

// Local Variables:
// mode: C++
// c-basic-offset: 4
// indent-tabs-mode: nil
// End:
